Simple test
------------

Ensure your device works with this simple test.

.. literalinclude:: ../examples/led_animation_simpletest.py
    :caption: examples/led_animation_simpletest.py
    :linenos:
